==> haskell-cryptonite-conduit-0.2.2-631-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-HXxVBISttn76oU8re6Dlu7
key:                  cryptonite-conduit-0.2.2-HXxVBISttn76oU8re6Dlu7
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  a21818ebce0a463bd85823d2967932f0
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-HXxVBISttn76oU8re6Dlu7
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.5-7HSqKM5SWt3UpRibGqqjq
    conduit-extra-1.3.6-BGazDEA0GeF3O5gK7s0pLG
    cryptonite-0.30-LsRhgAckSKm5u94QG0gjvR exceptions-0.10.4
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    resourcet-1.2.6-AkuAfAqfUrLC3kiGqtKSRc transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cryptonite-conduit-0.2.2-632-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-cryptonite-conduit.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 cryptonite-conduit
version:              0.2.2
visibility:           public
id:                   cryptonite-conduit-0.2.2-6rOgIJEZq6rASnJBr1vF07
key:                  cryptonite-conduit-0.2.2-6rOgIJEZq6rASnJBr1vF07
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           vincent@snarc.org
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             https://github.com/haskell-crypto/cryptonite-conduit
synopsis:             cryptonite conduit
description:
    Conduit bridge for cryptonite

    For now only provide a conduit version for hash and hmac, but
    with contribution, this could provide cipher conduits too,
    and probably other things.

category:             Cryptography, Conduit
abi:                  0070ab8b6ef5b9030a44dc9a0457354c
exposed:              True
exposed-modules:
    Crypto.Cipher.ChaChaPoly1305.Conduit Crypto.Hash.Conduit
    Crypto.MAC.HMAC.Conduit Crypto.PubKey.ECIES.Conduit

import-dirs:          /usr/lib/ghc-9.2.8/site-local/cryptonite-conduit-0.2.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/cryptonite-conduit-0.2.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-cryptonite-conduit
hs-libraries:         HScryptonite-conduit-0.2.2-6rOgIJEZq6rASnJBr1vF07
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    conduit-1.3.5-Frih06Q3cRoAcqwzA1ZmBK
    conduit-extra-1.3.6-890LOSfyKyeKLqBaCvku01
    cryptonite-0.30-LsRhgAckSKm5u94QG0gjvR exceptions-0.10.4
    memory-0.18.0-Hvum6HaH78UJG59LYyNLK1
    resourcet-1.2.6-AkuAfAqfUrLC3kiGqtKSRc transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-cryptonite-conduit/html/cryptonite-conduit.haddock

haddock-html:         /usr/share/doc/haskell-cryptonite-conduit/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
